@@ -1,11 +1,11 @@
 package Dist::Inkt::Role::DetermineRightsFromRdf;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.022';
+our $VERSION   = '0.100';
 
 use Moose::Role;
 use RDF::Trine qw( iri literal statement variable );
-use List::MoreUtils qw( uniq );
+use List::Util qw( uniq );
 use Path::Tiny qw( path );
 use Path::Iterator::Rule;
 use Software::License;
